@@ -396,6 +396,25 @@ function select_by_gender (phrase, form_m, form_f, form_n)
 setcalls("по-роду", select_by_gender);
 // "Delete $[callname %1 this thisa thiso] %1?"
 
+// ------------------------------
+// Select one of two forms according to the number of the phrase.
+function select_by_number (phrase, form_s, form_p)
+{
+    // Select number (default to singular if not found).
+    var number = "ј";
+    if (hasprop(phrase, "_број")) {
+        number = getprop(phrase, "_број");
+    }
+
+    if (number == "к") { // plural
+        return form_p;
+    } else {
+        return form_s;
+    }
+}
+setcalls("по-броју", select_by_number);
+// "%1 $[callname %1 waalks waalk] by the river."
+
 // ------------------------------
 // Select one of six forms according to the gender and number of the phrase.
 function select_by_number_gender (phrase,
@@ -508,6 +527,7 @@ function apply_to_word (/* phrase, callname, ...args before word... */)
     return str;
 }
 setcalls("на-реч", apply_to_word);
+setcalls("на-ријеч", apply_to_word);
 // "Repeat until $[callname casecall %1], and on this date..."
 
 // ------------------------------
